#[non_exhaustive]pub struct CreateBackupRequest {
pub parent: String,
pub backup_id: String,
pub backup: Option<Backup>,
pub request_id: String,
/* private fields */
}Expand description
Request message for DataprocMetastore.CreateBackup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The relative resource name of the service in which to create a backup of the following form:
projects/{project_number}/locations/{location_id}/services/{service_id}.
backup_id: StringRequired. The ID of the backup, which is used as the final component of the backup’s name.
This value must be between 1 and 64 characters long, begin with a letter, end with a letter or number, and consist of alpha-numeric ASCII characters or hyphens.
backup: Option<Backup>Required. The backup to create. The name field is ignored. The ID of the
created backup must be provided in the request’s backup_id field.
request_id: StringOptional. A request ID. Specify a unique request ID to allow the server to ignore the request if it has completed. The server will ignore subsequent requests that provide a duplicate request ID for at least 60 minutes after the first request.
For example, if an initial request times out, followed by another request with the same request ID, the server ignores the second request to prevent the creation of duplicate commitments.
The request ID must be a valid UUID A zero UUID (00000000-0000-0000-0000-000000000000) is not supported.
Implementations
Sourceimpl CreateBackupRequest
impl CreateBackupRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_backup_id<T: Into<String>>(self, v: T) -> Self
pub fn set_backup_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_backup<T>(self, v: T) -> Self
pub fn set_backup<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_backup<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_backup<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateBackupRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateBackupRequest
impl Clone for CreateBackupRequest
Sourcefn clone(&self) -> CreateBackupRequest
fn clone(&self) -> CreateBackupRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateBackupRequest
impl Debug for CreateBackupRequest
Sourceimpl Default for CreateBackupRequest
impl Default for CreateBackupRequest
Sourcefn default() -> CreateBackupRequest
fn default() -> CreateBackupRequest
Sourceimpl Message for CreateBackupRequest
impl Message for CreateBackupRequest
Sourceimpl PartialEq for CreateBackupRequest
impl PartialEq for CreateBackupRequest
Sourcefn eq(&self, other: &CreateBackupRequest) -> bool
fn eq(&self, other: &CreateBackupRequest) -> bool
self and other values to be equal, and is used by ==.