#[non_exhaustive]pub struct CreateMetadataImportRequest {
pub parent: String,
pub metadata_import_id: String,
pub metadata_import: Option<MetadataImport>,
pub request_id: String,
/* private fields */
}Expand description
Request message for DataprocMetastore.CreateMetadataImport.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The relative resource name of the service in which to create a metastore import, in the following form:
projects/{project_number}/locations/{location_id}/services/{service_id}.
metadata_import_id: StringRequired. The ID of the metadata import, which is used as the final component of the metadata import’s name.
This value must be between 1 and 64 characters long, begin with a letter, end with a letter or number, and consist of alpha-numeric ASCII characters or hyphens.
metadata_import: Option<MetadataImport>Required. The metadata import to create. The name field is ignored. The
ID of the created metadata import must be provided in the request’s
metadata_import_id field.
request_id: StringOptional. A request ID. Specify a unique request ID to allow the server to ignore the request if it has completed. The server will ignore subsequent requests that provide a duplicate request ID for at least 60 minutes after the first request.
For example, if an initial request times out, followed by another request with the same request ID, the server ignores the second request to prevent the creation of duplicate commitments.
The request ID must be a valid UUID A zero UUID (00000000-0000-0000-0000-000000000000) is not supported.
Implementations
Sourceimpl CreateMetadataImportRequest
impl CreateMetadataImportRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_metadata_import_id<T: Into<String>>(self, v: T) -> Self
pub fn set_metadata_import_id<T: Into<String>>(self, v: T) -> Self
Sets the value of metadata_import_id.
Example
let x = CreateMetadataImportRequest::new().set_metadata_import_id("example");Sourcepub fn set_metadata_import<T>(self, v: T) -> Selfwhere
T: Into<MetadataImport>,
pub fn set_metadata_import<T>(self, v: T) -> Selfwhere
T: Into<MetadataImport>,
Sets the value of metadata_import.
Example
use google_cloud_metastore_v1::model::MetadataImport;
let x = CreateMetadataImportRequest::new().set_metadata_import(MetadataImport::default()/* use setters */);Sourcepub fn set_or_clear_metadata_import<T>(self, v: Option<T>) -> Selfwhere
T: Into<MetadataImport>,
pub fn set_or_clear_metadata_import<T>(self, v: Option<T>) -> Selfwhere
T: Into<MetadataImport>,
Sets or clears the value of metadata_import.
Example
use google_cloud_metastore_v1::model::MetadataImport;
let x = CreateMetadataImportRequest::new().set_or_clear_metadata_import(Some(MetadataImport::default()/* use setters */));
let x = CreateMetadataImportRequest::new().set_or_clear_metadata_import(None::<MetadataImport>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateMetadataImportRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateMetadataImportRequest
impl Clone for CreateMetadataImportRequest
Sourcefn clone(&self) -> CreateMetadataImportRequest
fn clone(&self) -> CreateMetadataImportRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateMetadataImportRequest
impl Debug for CreateMetadataImportRequest
Sourceimpl Default for CreateMetadataImportRequest
impl Default for CreateMetadataImportRequest
Sourcefn default() -> CreateMetadataImportRequest
fn default() -> CreateMetadataImportRequest
Sourceimpl PartialEq for CreateMetadataImportRequest
impl PartialEq for CreateMetadataImportRequest
Sourcefn eq(&self, other: &CreateMetadataImportRequest) -> bool
fn eq(&self, other: &CreateMetadataImportRequest) -> bool
self and other values to be equal, and is used by ==.