CreateServiceRequest

Struct CreateServiceRequest 

#[non_exhaustive]
pub struct CreateServiceRequest { pub parent: String, pub service_id: String, pub service: Option<Service>, pub request_id: String, /* private fields */ }
Request message for DataprocMetastore.CreateService.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The relative resource name of the location in which to create a metastore service, in the following form:

projects/{project_number}/locations/{location_id}.

service_id: String

Required. The ID of the metastore service, which is used as the final component of the metastore service’s name.

This value must be between 2 and 63 characters long inclusive, begin with a letter, end with a letter or number, and consist of alpha-numeric ASCII characters or hyphens.

service: Option<Service>

Required. The Metastore service to create. The name field is ignored. The ID of the created metastore service must be provided in the request’s service_id field.

request_id: String

Optional. A request ID. Specify a unique request ID to allow the server to ignore the request if it has completed. The server will ignore subsequent requests that provide a duplicate request ID for at least 60 minutes after the first request.

For example, if an initial request times out, followed by another request with the same request ID, the server ignores the second request to prevent the creation of duplicate commitments.

The request ID must be a valid UUID A zero UUID (00000000-0000-0000-0000-000000000000) is not supported.

Implementations

Source

impl CreateServiceRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = CreateServiceRequest::new().set_parent(format!("projects/{project_id}/locations/{location_id}"));
pub fn set_service_id<T: Into<String>>(self, v: T) -> Self

Sets the value of service_id.

Example
let x = CreateServiceRequest::new().set_service_id("example");
pub fn set_service<T>(self, v: T) -> Self
where T: Into<Service>,

Sets the value of service.

Example
use google_cloud_metastore_v1::model::Service;
let x = CreateServiceRequest::new().set_service(Service::default()/* use setters */);
pub fn set_or_clear_service<T>(self, v: Option<T>) -> Self
where T: Into<Service>,

Sets or clears the value of service.

Example
use google_cloud_metastore_v1::model::Service;
let x = CreateServiceRequest::new().set_or_clear_service(Some(Service::default()/* use setters */));
let x = CreateServiceRequest::new().set_or_clear_service(None::<Service>);
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self

Sets the value of request_id.

Example
let x = CreateServiceRequest::new().set_request_id("example");