#[non_exhaustive]pub struct MoveTableToDatabaseRequest {
pub service: String,
pub table_name: String,
pub db_name: String,
pub destination_db_name: String,
/* private fields */
}Expand description
Request message for DataprocMetastore.MoveTableToDatabase.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.service: StringRequired. The relative resource name of the metastore service to mutate metadata, in the following format:
projects/{project_id}/locations/{location_id}/services/{service_id}.
table_name: StringRequired. The name of the table to be moved.
db_name: StringRequired. The name of the database where the table resides.
destination_db_name: StringRequired. The name of the database where the table should be moved.
Implementations
Sourceimpl MoveTableToDatabaseRequest
impl MoveTableToDatabaseRequest
Sourcepub fn set_service<T: Into<String>>(self, v: T) -> Self
pub fn set_service<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_table_name<T: Into<String>>(self, v: T) -> Self
pub fn set_table_name<T: Into<String>>(self, v: T) -> Self
Sets the value of table_name.
Example
ⓘ
let x = MoveTableToDatabaseRequest::new().set_table_name("example");Sourcepub fn set_db_name<T: Into<String>>(self, v: T) -> Self
pub fn set_db_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_destination_db_name<T: Into<String>>(self, v: T) -> Self
pub fn set_destination_db_name<T: Into<String>>(self, v: T) -> Self
Sets the value of destination_db_name.
Example
ⓘ
let x = MoveTableToDatabaseRequest::new().set_destination_db_name("example");Trait Implementations
Sourceimpl Clone for MoveTableToDatabaseRequest
impl Clone for MoveTableToDatabaseRequest
Sourcefn clone(&self) -> MoveTableToDatabaseRequest
fn clone(&self) -> MoveTableToDatabaseRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MoveTableToDatabaseRequest
impl Debug for MoveTableToDatabaseRequest
Sourceimpl Default for MoveTableToDatabaseRequest
impl Default for MoveTableToDatabaseRequest
Sourcefn default() -> MoveTableToDatabaseRequest
fn default() -> MoveTableToDatabaseRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for MoveTableToDatabaseRequest
impl Message for MoveTableToDatabaseRequest
Sourceimpl PartialEq for MoveTableToDatabaseRequest
impl PartialEq for MoveTableToDatabaseRequest
Sourcefn eq(&self, other: &MoveTableToDatabaseRequest) -> bool
fn eq(&self, other: &MoveTableToDatabaseRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MoveTableToDatabaseRequest