#[non_exhaustive]pub struct CreateServiceRequest {
pub parent: String,
pub service_id: String,
pub service: Option<Service>,
pub request_id: String,
/* private fields */
}Expand description
Request message for DataprocMetastore.CreateService.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The relative resource name of the location in which to create a metastore service, in the following form:
projects/{project_number}/locations/{location_id}.
service_id: StringRequired. The ID of the metastore service, which is used as the final component of the metastore service’s name.
This value must be between 2 and 63 characters long inclusive, begin with a letter, end with a letter or number, and consist of alpha-numeric ASCII characters or hyphens.
service: Option<Service>Required. The Metastore service to create. The name field is
ignored. The ID of the created metastore service must be provided in
the request’s service_id field.
request_id: StringOptional. A request ID. Specify a unique request ID to allow the server to ignore the request if it has completed. The server will ignore subsequent requests that provide a duplicate request ID for at least 60 minutes after the first request.
For example, if an initial request times out, followed by another request with the same request ID, the server ignores the second request to prevent the creation of duplicate commitments.
The request ID must be a valid UUID A zero UUID (00000000-0000-0000-0000-000000000000) is not supported.
Implementations
Sourceimpl CreateServiceRequest
impl CreateServiceRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_service_id<T: Into<String>>(self, v: T) -> Self
pub fn set_service_id<T: Into<String>>(self, v: T) -> Self
Sets the value of service_id.
Example
let x = CreateServiceRequest::new().set_service_id("example");Sourcepub fn set_service<T>(self, v: T) -> Self
pub fn set_service<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_service<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_service<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateServiceRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateServiceRequest
impl Clone for CreateServiceRequest
Sourcefn clone(&self) -> CreateServiceRequest
fn clone(&self) -> CreateServiceRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateServiceRequest
impl Debug for CreateServiceRequest
Sourceimpl Default for CreateServiceRequest
impl Default for CreateServiceRequest
Sourcefn default() -> CreateServiceRequest
fn default() -> CreateServiceRequest
Sourceimpl Message for CreateServiceRequest
impl Message for CreateServiceRequest
Sourceimpl PartialEq for CreateServiceRequest
impl PartialEq for CreateServiceRequest
Sourcefn eq(&self, other: &CreateServiceRequest) -> bool
fn eq(&self, other: &CreateServiceRequest) -> bool
self and other values to be equal, and is used by ==.